@@ -1,10 +1,10 @@
 ;;; cdr255.el --- Yewscion's Elisp Library           -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2023  Claire Rodriguez
+;; Copyright (C) 2025 Claire Rodriguez
 
-;; Author: Claire Rodriguez
-;; Version: 0.0.1
+;; Author: Claire Rodriguez <yewscion@gmail.com>
 ;; Keywords: lisp
+;; Version: 0.0.3
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-
 ;;; Commentary:
 
 ;; 
@@ -664,6 +663,261 @@ None."
    (s-lines
     (f-read file))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;  [2024-09-16 Mon 10:32]  ;;;;;;;;;;;;;;;;;;;;;;;;
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(defun cdr255:eval-string (item)
+  "Evaluates ITEM as a piece of Emacs Lisp code."
+    (eval (car (read-from-string (format "(progn %s)" item)))))
+
+(defun cdr255:get-prior-sexp-coords ()
+  "Get the nearest prior S-expression's coordinates as a cons cell.
+
+This is an ACTION.
+
+Arguments
+=========
+
+None.
+
+Returns
+=======
+
+A <cons cell> like <<char-number><char-number>>, with the first
+value being the start of the prior S-expression, and the last
+value being the end of the prior S-expression.
+
+Impurities
+==========
+
+Relies on the current buffer state."
+  (save-mark-and-excursion
+    (let ((end (point)))
+      (thing-at-point--beginning-of-sexp)
+      (cons (point) end))))
+
+(defun cdr255:get-prior-sexp-as-string ()
+  "Get the nearest prior S-expression as a string.
+
+This is an ACTION.
+
+Arguments
+=========
+
+None.
+
+Returns
+=======
+
+A <string> representing the nearest prior S-expression.
+
+Impurities
+==========
+
+Relies on the current buffer state."
+  (let ((coords (cdr255:get-prior-sexp-coords)))
+    (buffer-substring-no-properties (car coords) (cdr coords))))
+
+(defun cdr255:format-princ (value)
+  "Generate a string representing value as a human-readable string.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+VALUE <object>: This is what we are generating a string to represent.
+
+Returns
+=======
+
+A <string> representing the VALUE as a human-readable string.
+
+Impurities
+==========
+
+None."
+  (format "%s" value))
+(defun cdr255:format-prin1 (value)
+  "Generate a string representing value as an S-expression.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+VALUE <object>: This is what we are generating a string to represent.
+
+Returns
+=======
+
+A <string> representing the VALUE as an S-expression.
+
+Impurities
+==========
+
+None."  
+  (format "%S" value))
+(defun cdr255:format-2-digit (value)
+  "Generate a string representing value as a 2 digit integer.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+VALUE <object>: This is what we are generating a string to represent.
+
+Returns
+=======
+
+A <string> representing the VALUE as a 2 digit integer.
+
+Impurities
+==========
+
+None."  
+  (format "%02d" value))
+(defun cdr255:format-2-mantissa (value)
+  "Generate a string representing value as a number in base 10 with a mantissa of length 2.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+VALUE <object>: This is what we are generating a string to represent.
+
+Returns
+=======
+
+A <string> representing the VALUE as a number in base 10 with a mantissa of length 2.
+
+Impurities
+==========
+
+None."  
+  (format "%0.2f" value))
+
+(defun cdr255:eval-sexp-string-to-proper-string (sexp-string)
+  "Generates a string representing the result of evaluating
+SEXP-STRING, with some opinionated ways of representing various
+types of values.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+SEXP-STRING <string>: A representation of a valid S-expression
+that we will be evaluating a using as a basis for our generated
+string.
+
+Returns
+=======
+
+A <string> representing the result of evaluating SEXP-STRING.
+
+Impurities
+==========
+
+None, assuming the S-Expression supplied as SEXP-STRING is pure."
+  (let ((result (cdr255:eval-string sexp-string)))
+    (cond
+     ((stringp result) (cdr255:format-princ result))
+     ((= (round result) result) (cdr255:format-2-digit result))
+     ((numberp result) (cdr255:format-2-mantissa result))
+     (t (cdr255:format-prin1 result)))))
+
+(defun cdr255:eval-prior-sexp-to-string ()
+  "Returns the result of evaluating the nearest prior S-expression as a string.
+
+This is an ACTION.
+
+Arguments
+=========
+
+None.
+
+Returns
+=======
+
+A <string> representing the result of evaluating the nearest prior S-expression.
+
+Impurities
+==========
+
+Relies on current buffer state."
+  (cdr255:eval-sexp-string-to-proper-string (cdr255:get-prior-sexp-as-string)))
+
+(defun cdr255:eval-prior-sexp-message ()
+  "Displays the result of evaluating the nearest prior S-expression as a message.
+
+This is an ACTION.
+
+Arguments
+=========
+
+None.
+
+Returns
+=======
+
+<undefined>
+
+Impurities
+==========
+
+Relies on current buffer state, undefined return value."
+  (interactive)
+  (message (cdr255:eval-prior-sexp-to-string)))
+
+(defun cdr255:eval-prior-sexp-insert ()
+  "Inserts the result of evaluating the nearest prior S-expression at point.
+
+This is an ACTION.
+
+Arguments
+=========
+
+None.
+
+Returns
+=======
+
+<undefined>
+
+Impurities
+==========
+
+Relies on and modifies current buffer state, undefined return value."
+  (interactive)
+  (insert (cdr255:eval-prior-sexp-to-string)))
+
+(defun cdr255:eval-prior-sexp-replace ()
+  "Inserts the result of evaluating the nearest prior S-expression at point, removing the S-expression.
+
+This is an ACTION.
+
+Arguments
+=========
+
+None.
+
+Returns
+=======
+
+<undefined>
+
+Impurities
+==========
+
+Relies on and modifies current buffer state, undefined return value."
+  (interactive)
+  (let ((coords (cdr255:get-prior-sexp-coords)))
+    (insert (cdr255:eval-prior-sexp-to-string))
+    (delete-region (car coords) (cdr coords))))
 
 (provide 'cdr255)
 ;;; cdr255.el ends here
